{
    package GCLang::RO;

    use utf8;
###################################################
#
#  Copyright 2005 Tian
#
#  This file is part of GCfilms.
#
#  GCfilms is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCfilms is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCfilms; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (

        'LangName' => 'Română',
        
        'Separator' => ': ',
        
        'Warning' => '<b>Atenţie</b>:
        
Informaţiile transferate de pe siturile web (prin intermediul
modulelor de căutare) sunt <b>doar pentru uz personal</b>.

Orice redistribuire este interzisă fără <b>autorizarea
explicită</b> a sitului web.

Pentru a determina ce sit web este proprietarul informaţiei,
puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
        
        'AllMoviesFiltered' => 'Nici un film nu se potriveşte criteriilor dumneavoastră de filtrare',
        
	'InstallDirInfo' => 'Instalare în ',
	'InstallMandatory' => 'Componente obligatorii',
	'InstallOptional' => 'Componente opţionale',
	'InstallErrorMissing' => 'Eroare : Următoarele componente Perl trebuie instalate: ',
	'InstallPrompt' => 'Directorul principal pentru instalare [/usr/local]: ',
	'InstallEnd' => 'Sfârşitul instalării',
	'InstallNoError' => 'Nici o eroare',
	'InstallLaunch' => 'Pentru a folosi acestă aplicaţie, se poate porni ',
	'InstallDirectory' => 'Directorul principal',
	'InstallTitle' => 'Instalare GCfilms',
	'InstallDependencies' => 'Dependinţe',
    'InstallPath' => 'Cale',
    'InstallOptions' => 'Opţiuni',
	'InstallSelectDirectory' => 'Selectaţi directorul principal pentru instalare',
	'InstallWithClean' => 'Şterge fişierele aflate în directorul de instalare',
	'InstallWithMenu' => 'Adaugă GCfilms la meniul Aplicaţii',
	'InstallNoPermission' => 'Eroare: Nu aveţi permisiunile necesare pentru a scrie în directorul selectat',
	'InstallMissingMandatory' => 'Dependinţe esenţiale lipsesc. Nu veţi putea instala GCFilms până când acestea nu vor fi prezente pe sistemul dumneavoastră.',
	'InstallMissingOptional' => 'Unele dependinţe opţionale lipsesc. Acestea sunt listate mai jos. GCfilms poate fi instalat dar unele facilităţi ar putea să nu fie disponibile.',
	'InstallMissingNone' => 'Toate dependinţele sunt satisfăcute. Puteţi continua cu instalarea GCfilms.',
	'InstallOK' => 'OK',
	'InstallMissing' => 'Lipsă',
	'InstallMissingFor' => 'Lipsă pentru',

#Splash
	'SplashInit' => 'Iniţializare',
	'SplashLoad' => 'Încărcare colecţie',
	'SplashDone' => 'Gata',

#Menus
	'MenuMovies' => '_Fişier',
		'MenuNewList' => 'Colecţie _nouă',
		'MenuHistory' => 'Colecţii _recente',
		'MenuLend' => 'Afişează filmele î_mprumutate',
		'MenuImport' => '_Importă',	
		'MenuExport' => '_Exportă',

	'MenuEdit'  => '_Editare',
   	    'MenuDuplicate' => '_Duplică film',
		'MenuEditDeleteCurrent' => 'Ş_terge film',
		'MenuEditLockMovies' => 'B_lochează colecţia',

	'MenuDisplay' => 'F_iltrare',
		'MenuViewAllMovies' => 'Afişează to_ate filmele',
		'MenuSearchMovies' => '_Caută',
			'MenuSearchAllMovies' => 'Caută în to_ate filmele',
			'MenuSearchSelectedMovies' => 'Caută în filmele a_fişate',
		'MenuSeenOrNot' => '_Vizionat',
			'MenuAllMovies' => '_Oricare',
			'MenuNotSeen' => '_Nevizionat',
		'MenuBorrowing' => '_Disponibil',
			'MenuBorrowed' => 'Î_mprumutat',
			'MenuNotBorrowed' => '_Disponibil',
        'MenuAge' => 'A_udienţă',
        'MenuAgeNone' => '_Toate vârstele',
        'MenuAgeParent' => 'Cu acord _parental',
        'MenuAgeLess' => '_Specifică vârsta...',
		'MenuCategories' => '_Gen',
			'MenuAllCategories' => '_Oricare',
		'MenuRating' => '_Evaluare',
			'MenuAllRating' => '_Oricare',
			'MenuChooseRating' => 'Evaluat la cel _puţin...',

	'MenuConfiguration' => '_Setări',
		'MenuDisplayOptions' => '_Informaţii afişate',
		'MenuBorrowers' => '_Persoane care au împrumutat',
        'MenuGenresConversion' => '_Conversie gen',
		'MenuRename' => 'Editare _gen',

	'MenuHelp' => '_Ajutor',
		'MenuAbout' => '_Despre GCfilms',

	'MenuNewWindow' => 'Afişează filmul în fereastră _nouă',

        'RemoveConfirm' => 'Sunteţi sigur că doriţi să ştergeţi acest film?',
        'NewMovie' => 'Film nou',
        'NewMovieTooltip' => 'Adaugă un film nou',
        'NoMovieFound' => 'Nici un film nu a fost găsit. Doriţi să căutaţi pe alt sit?',
        'OpenList' => 'Vă rugăm selectaţi colecţia',
        'SaveList' => 'Vă rugăm alegeţi unde să salvaţi colecţia',
        'SaveListTooltip' => 'Salvează colecţia curentă',
        'SaveCurrentList' => 'Mai întâi specificaţi unde să fie salvată colecţia curentă',
        'Movies' => 'Filme',
        'PreferencesTooltip' => 'Setaţi preferinţele dumneavoastră',
        'ViewTooltip' => 'Schimbă afişarea colecţiei',
        'PlayTooltip' => 'Redă fişierul video asociat acestui film',

        'StatusSearch' => 'Căutare în curs...',
        'StatusGetInfo' => 'Obţin informaţiile...',
        'StatusGetImage' => 'Obţin imaginea...',
                
        'SaveError' => 'Nu am putut salva lista de filme. Vă rugăm verificaţi drepturile de acces şi spaţiul liber pe disc.',
        'OpenError' => 'Nu am putut deschide lista de filme. Vă rugăm verificaţi drepturile de acces.',
        'ImageError' => 'Directorul selectat pentru a salva imaginile nu este corect. Vă rugăm selectaţi alt director.',
        'OptionsCreationError'=> 'Nu pot crea fişierul de opţiuni: ',
        'OptionsOpenError'=> 'Nu pot deschide fişierul de opţiuni: ',
        'OptionsSaveError'=> 'Nu pot salva fişierul de opţiuni: ',
        
        'RandomTooltip' => 'Ce să vedem în acestă seară?',
        'RandomError'=> 'Nu aveţi nici un film nevizionat',
        'RandomEnd'=> 'Nu mai sunt alte filme',
        'RandomNextTip'=> 'Următoarea sugestie',
        'RandomOkTip'=> 'Acceptă acest film',
        
        'AboutTitle' => 'Despre GCfilms',
        'AboutDesc' => 'Catalog de filme Gtk2',
        'AboutVersion' => 'Versiune',
        'AboutTeam' => 'Echipa',
        'AboutWho' => 'Tian: Manager de proiect, programator
MeV: Programator
Christophe Z: Programator
Adolfo González : Programator

Jason Day : Contributor
Gabriel Meier : Contributor

Dab : Contributor
rootII : Contributor
VFRMania : Contributor',
        'AboutLicense' => 'Distribuit în termenii licenţei GNU GPL
Copyright logo le Spektre
http://le-spektre.org',
        'AboutTranslation' => 'Traducerea în română de către Mugurel Tudor',
        'AboutDesign' => 'Logo şi design web de către le Spektre',

        'ToolbarRandom' => 'În seara asta',
        
        'ResultsTitle' => 'Selectaţi un film',
        'ResultsMovieTitle' => 'Titlu',
        'ResultsMovieYear' => 'An',
        'ResultsMovieDirector' => 'Regizor',
        'ResultsMovieActors' => 'Actori',
        'ResultsNextTip' => 'Caută pe următorul sit',
        
        'OptionsTitle' => 'Preferinţe',
        'OptionsBrowser' => 'Navigator web',
        'OptionsPlayer' => 'Player video',
        'OptionsImages' => 'Director de imagini',
        'OptionsUseRelativePaths' => 'Foloseşte căi relative pentru imagini',
        'OptionsOrder' => 'Layout',
        'OptionsStatus' => 'Afişează bara de status',
        'OptionsUrlPicture' => 'Afişează logo-ul sitului în butonul pentru pagina de web a filmului',
        'OptionsWarning' => 'Atenţie: Modificările din acest tab nu vor avea efect decât după repornirea aplicaţiei.',
        'OptionsTabs' => 'Taburi',
        'OptionsAllInOne' => 'O singură pagină',
        'OptionsCompact' => 'Compact',
        'OptionsReadOnly' => 'Doar pentru citire',
        'OptionsWebSite' => 'Situl web GCfilms',
        'OptionsRemoveConfirm' => 'Cere o confirmare înainte de ştergerea filmului',
        'OptionsAutoSave' => 'Salvează colecţia automat',
        'OptionsSplash' => 'Afişează ecranul de pornire',
        'OptionsImagesTitle' => 'Selectaţi un director',
        'OptionsBrowserTitle' => 'Selectaţi programul ce va fi folosit',
		'OptionsPlugins' => 'Situl de la care se vor obţine informaţiile',
		'OptionsAskPlugins' => 'Întreabă (toate siturile)',
		'OptionsPluginsMulti' => 'Multe situri',
		'OptionsPluginsMultiAsk' => 'Întreabă (multe situri)',
		'OptionsPluginsList' => 'Setează lista',
        'OptionsAskImport' => 'Selectează câmpurile ce vor fi importate',
		'OptionsProxy' => 'Foloseşte un proxy',
        'OptionsLang' => 'Limbă',
        'OptionsMain' => 'Principal',
        'OptionsPaths' => 'Căi',
        'OptionsInternet' => 'Internet',
        'OptionsConveniences' => 'Facilităţi',
        'OptionsDisplay' => 'Afişare',
        'OptionsToolbar' => 'Bară de unelte',
        'OptionsToolbars' => {0 => 'Fără', 1 => 'Mică', 2 => 'Mare'},
        'OptionsToolbarPosition' => 'Poziţie',
        'OptionsToolbarPositions' => {0 => 'Sus', 1 => 'Jos', 2 => 'Stânga', 3 => 'Dreapta'},
        'OptionsView' => 'Afişare',
        'OptionsViews' => {0 => 'Text', 1 => 'Imagine', 2 => 'Detalii'},
        'OptionsColumns' => 'Coloane',
        'OptionsMailer' => 'Trimitere email',
        'OptionsSMTP' => 'Server',
        'OptionsFrom' => 'Email-ul dumneavoastră',
        'OptionsTransform' => 'Plasează articolele la sfârşitul titlurilor',
        'OptionsArticles' => 'Articole (separate prin virgulă)',
        'OptionsFormats' => 'Tipuri media (separate prin virgulă)',
        'OptionsSearchStop' => 'Permite întreruperea căutărilor',
        'OptionsAlwaysOriginal' => 'Foloseşte titlul principal ca titlu original în cazul în care acesta nu este prezent',
        'OptionsHistory' => 'Mărime istoric',
        'OptionsClearHistory' => 'Şterge istoricul',
		'OptionsStyle' => 'Temă',
        'OptionsDontAsk' => 'Nu mai întreba din nou',

        'ImagesOptionsButton' => 'Setări',
        'ImagesOptionsTitle' => 'Setări pentru lista de imagini',
        'ImagesOptionsSelectColor' => 'Selectaţi o culoare',
        'ImagesOptionsBg' => 'Fundal',
        'ImagesOptionsBgPicture' => 'Foloseşte o imagine de fundal',
        'ImagesOptionsFg'=> 'Selecţie',
        'ImagesOptionsBgTooltip' => 'Schimbă culoarea pentru fundal',
        'ImagesOptionsFgTooltip'=> 'Schimbă culoarea pentru selecţie',
        'ImagesOptionsSizeLabel' => 'Mărime',
        'ImagesOptionsSizeList' => {0 => 'Foarte mică', 1 => 'Mică', 2 => 'Medie', 3 => 'Mare', 4 => 'Foarte mare'},
        'ImagesOptionsSizeTooltip' => 'Selectaţi mărimea imaginii',
		        
        'DetailedOptionsTitle' => 'Setări pentru lista detaliată',
        'DetailedOptionsImageSize' => 'Mărime imagini',
        'DetailedOptionsGroupMovies' => 'Grupează filmele după colecţie',
		'DetailedOptionsFields' => 'Selectează câmpurile afişate',

        'ExtractButton' => 'Informaţii',
        'ExtractTitle' => 'Informaţii fişier video',
        'ExtractSize' => 'Mărime',
        'ExtractLength' => 'Durată (minute)',
        'ExtractType' => 'Format video',
        'ExtractAudioEncoding' => 'Format audio',
        'ExtractImport' => 'Foloseşte valorile',

        'ExportTitle' => 'Exportă lista de filme',
        'ExportFilter' => 'Exportă doar filmele afişate',
        'ImportListTitle' => 'Importă altă listă de filme',
        'ImportExportFile' => 'Fişier',
        'ImportExportSave' => 'Vă rugăm selectaţi fişierul pentru folosire',
        'ImportExportFieldsUnused' => 'Câmpuri nefolosite',
        'ImportExportFieldsUsed' => 'Câmpuri folosite',
        'ImportExportFieldsFill' => 'Adaugă toate',
        'ImportExportFieldsClear' => 'Şterge toate',
        'ImportExportFieldsEmpty' => 'Trebuie să alegeţi cel puţin un câmp',
        'ImportExportFileEmpty' => 'Trebuie să specificaţi un nume de fişier',
        'ExportFieldsTitle' => 'Câmpurile ce vor fi exportate',
        'ExportFieldsTip' => 'Selectaţi câmpurile pe care doriţi să le exportaţi',
        'ImportFieldsTitle' => 'Câmpurile ce vor fi importate',
        'ImportFieldsTip' => 'Selectaţi câmpurile pe care le doriţi importate',
        'ImportNewList' => 'Creează o nouă colecţie',
        'ImportCurrentList' => 'Adaugă la colecţia curentă',
        'ImportDropError' => 'A intervenit o eroare la deschiderea a cel puţin unui fişier. Listă precedentă va fi reîncărcată.',

        'FileOverwrite' => 'Acest fişier deja există. Doriţi să îl suprascrieţi?',

        'PanelSearchButton' => 'Obţine informaţii',
        'PanelSearchTip' => 'Caută pe web informaţii despre acest titlu',
        'PanelSeenYes' => 'Vizionat',
        'PanelSeenNo' => 'Nevizionat',
        'PanelLanguages' => 'Limbi',
        'PanelEncoding' => 'Codare',
        'PanelImageTip' => 'Clic pe imagine pentru a selecta alta. Clic dreapta pentru mai multe opţiuni.',
        'PanelImageTitle' => 'Selectaţi o imagine',
        'PanelTrailerTitle' => 'Selectaţi un fişier',
        'PanelInfoFrame' => 'Informaţii',
        'PanelAgeUnknown' => 'Neevaluat',
        'PanelAgeNone' => 'Toate vârstele',
        'PanelAgeParent' => 'Acord parental',
        'PanelNobody' => 'Nimeni',
        'PanelUnknown' => 'Necunoscut',
        'PanelLendedYes' => 'Împrumutat',
        'PanelLendedNo' => 'Disponibil',
        'PanelLendDateSelect' => 'Selectaţi o dată',
        'PanelReturned' => 'Film returnat',
        'PanelRemove' =>'Şterge',
        'PanelClear' =>'Şterge tot',
        'PanelReturnDate' => 'Data returnării',
        'PanelWeb' => 'Mai multe informaţii',
        'PanelWebTip' => 'Afişează informaţii de pe web despre acest film',
        'PanelRemoveTip' => 'Şterge filmul curent',
        'PanelMovieInfo' => 'General',
        'PanelPrivateInfo' => 'Detalii',
        'PanelLendInfo' => 'Împrumuturi',

        'ToolbarAll' => 'Afişează tot',
        'ToolbarAllTooltip' => 'Afişează toate filmele',
        
        'RatingTitle' => 'Evaluare minimă',
        'RatingLabel' => 'Următoarea valoare este evaluarea minimă pe care trebuie să o aibă un film pentru a fi afişat',

        'AgeTitle' => 'Vârsta audienţei:',
        'AgeLabel' => 'Doar filmele potrivite pentru persoane de această vârstă vor fi afişate',

        'StatusMovies' => 'Filme',
        
        'PluginsTitle' => 'Cautare filme',
        'PluginsFrame' => 'Sit pentru căutare',
        'PluginsLogo' => 'Logo',
        'PluginsName' => 'Nume',
        'PluginsAuthor' => 'Autor',
        'PluginsLang' => 'Limbă',
        'PluginsUseSite' => 'Foloseşte situl selectat pentru viitoarele căutări',

        'BorrowersTitle' => 'Configurare împrumuturi',
        'BorrowersName' => 'Nume',
        'BorrowersEmail' => 'E-mail',
        'BorrowersAdd' => 'Adaugă',
        'BorrowersRemove' => 'Şterge',
        'BorrowersEdit' => 'Editează',
        'BorrowersTemplate' => 'Şablon mail',
        'BorrowersSubject' => 'Subiect mail',
        'BorrowersNotice1' => '%1 va fi înlocuit cu numele celui care a împrumutat',
        'BorrowersNotice2' => '%2 va fi înlocuit cu numele filmului',
        'BorrowersNotice3' => '%3 va fi înlocuit cu data împrumutării',

        'BorrowedTitle' => 'Filme împrumutate',
        'BorrowedMovie' => 'Film',
        'BorrowedName' => 'Persoana care a împrumutat',
        'BorrowedDate' => 'Din data de',

        'MailTitle' => 'Trimite un email',
        'MailFrom' => 'De la: ',
        'MailTo' => 'Către: ',
        'MailSubject' => 'Subiect: ',
        'MailSmtpError' => 'Problemă la conectarea la serverul SMTP',
        'MailSendmailError' => 'Problemă la lansarea sendmail',

        'SearchTooltip' => 'Caută toate filmele',
        'SearchTitle' => 'Căutare film',
        'SearchMovieTitle' => 'Titlul conţine:',
        'SearchRating' => 'Evaluat la cel puţin:',
        'SearchDirector' => 'Regizor:',
        'SearchActors' => 'Distribuţie (separată prin virgulă):',
        'SearchType' => 'Gen:',
        'SearchSeen' => 'Vizionat:',
        'SearchUndef' => 'Nu contează',
        'SearchSeenYes' => 'Da',
        'SearchSeenNo' => 'Nu',
        'SearchAge' => 'Vârstă public:',
        'SearchYear' => 'An între',
        'SearchYearBetween' => 'şi',

        'RenameTitle' => 'Editare genuri',
        'RenameOld' => 'Numele actual',
        'RenameNew' => 'Noul nume',
        
        'ImportWindowTitle' => 'Selectaţi câmpurile pentru import',
        'ImportViewPicture' => 'Afişează imaginea',
        'ImportSelectAll' => 'Selectează tot',
        'ImportSelectNone' => 'Nu selecta nimic',

        'ExportTarGzInfo' => 'Arhiva este în fişierul: ',

        'ExportHTMLWithJS' => 'Foloseşte Javascript',
       	'ExportHTMLFileTemplate' => 'Şablon :',
        'ExportHTMLPreview' => 'Previzualizare',
        'ExportHTMLNoPreview' => 'Previzualizare nedisponibilă',
        'ExportHTMLTitle' => 'Titlu pagină',
        'ExportHTMLInfoFile' => 'Lista de filme este în fişierul: ',
        'ExportHTMLInfoDir' => 'Imaginile sunt în: ',
        'ExportHTMLHeightimg' => 'Înălţimea (în pixeli) a imaginilor exportate: ',
        'ExportHTMLOpenFileInBrowser' => 'Deschide fişierul generat într-un navigator web',
        'ExportHTMLNote' => 'Listă generată de către <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
        'ExportHTMLInputTitle' => 'Introduceţi textul pentru căutare',
        'ExportHTMLSearchType1' => 'Doar titlul',
        'ExportHTMLSearchType2' => 'Informaţii complete',
        'ExportHTMLSearchButton' => 'Caută',    
        'ExportHTMLSearchTitle' => 'Afişează doar filmele ce se potrivesc criteriului precedent',
        'ExportHTMLAllButton' => 'Toate',
        'ExportHTMLAllTitle' => 'Afişează toate filmele',
        'ExportHTMLExpand' => 'Extinde tot',
        'ExportHTMLExpandTitle' => 'Afişează toate informaţiile filmelor',
        'ExportHTMLCollapse' => 'Restrânge tot',
        'ExportHTMLCollapseTitle' => 'Ascunde informaţiile filmelor',
        'ExportHTMLBorrowed' => 'Împrumutat de către: ',
        'ExportHTMLNotBorrowed' => 'Disponibil',
        'ExportHTMLTop' => 'Sus',
        
        'ExportSQLWithPictures' => 'Copiază imaginile într-un subdirector',
        'ExportSQLWithDrop' => 'Include instrucţiuni DROP',
        'ExportSQLWithCreate' => 'Include instrucţiuni CREATE',
        'ExportSQLTableName' => 'Nume tabel',
        'ExportSQLInfoFile' => 'Fişier SQL: ',
        
        'ExportXMLModelFile' => 'Fişier şablon',
        'ExportXMLModelText' => 'Şablon text',
        'ExportXMLModels' => 'Şablonul folosit',
        'ExportXMLUseFile' => 'Foloseşte fişier',
        'ExportXMLUseModel' => 'Foloseşte zona de text',

        'ExportCSVHeader' => 'Include numele câmpurilor în partea superioară',
        'ExportCSVSeparator' => 'Separator',
        'ExportCSVReplacement' => 'Înlocuieşte separatorul cu',

        'ImportCSVHeader' => 'Ignoră prima linie',

        'ImportListName' => 'Listă titluri',
        'ImportListPlugin' => 'Situl folosit',
        'ImportListUseFirst' => 'Selectaţi primul în caz de prea multe rezultate',
        'ImportListCommentAuto' => 'Film importat automat.',
        'ImportListCommentSite' => 'Sit web: ',
        'ImportListCommentTitle' => 'Titlu: ',

        'ImportTellicoNotVideo' => 'Fişierul nu este o colecţie video Tellico',

        'MultiSiteTitle' => 'Siturile folosite pentru căutări',
        'MultiSiteUnused' => 'Module nefolosite',
        'MultiSiteUsed' => 'Module ce vor fi folosite',
        'MultiSiteLang' => 'Umple lista cu module pentru limba engleză',
        'MultiSiteEmptyError' => 'Lista de situri este goală',
        'MultiSiteClear' => 'Şterge lista',

        'FieldsList' => {
            id => 'General: Id',
            title => 'General: Titlu',
            date => 'General: Dată',
            time => 'General: Durată',
            director => 'General: Regizor',
            nat => 'General: Ţară',
            age => 'General: Vârstă minimă',
            type => 'General: Gen',
            image => 'General: Imagine',
            orig => 'General: Titlu original',
            actors => 'General: Distribuţie',
            comment => 'Detalii: Comentarii',
            synopsis => 'General: Rezumat',
            seen => 'Detalii: Vizionat',
            number => 'Detalii: Numărul',
            rating => 'Detalii: Evaluare',
            format => 'Detalii: Mediu',
            url => 'Detalii: Web',
            place => 'Detalii: Locaţie',
            audio => 'Detalii: Audio',
            video => 'Detalii: Format video',
            trailer => 'Detalii : Fişier video',
            collection => 'Detalii: Colecţie',
            rank => 'Detalii: Poziţie',
            subt => 'Detalii: Subtitrări',
            borrower => 'Împrumuturi: Împrumutat de',
            lendDate => 'Împrumuturi: Din data de',
            history => 'Împrumuturi: Istoric împrumuturi',
        },
        
        'DisplayOptionsTitle' => 'Elemente afişate',
        'DisplayOptionsAll' => 'Selectează tot',
        'DisplayOptionsMain' => 'Elemente principale',
        'DisplayOptionsActions' => 'Butoane acţiune',
        'DisplayOptionsSearch' => 'Buton căutare',

        'GenresTitle' => 'Conversie gen',
        'GenresCategoryName' => 'Genul de folosit',
        'GenresCategoryMembers' => 'Genul de înlocuit',
        'GenresLoad' => 'Încarcă o listă',
        'GenresExport' => 'Salvează lista într-un fişier',
        'GenresModify' => 'Editează conversia',
    );
}
1;
